==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/LoT/AwsIoTAnalyticsDataset.md <==
# AwsIoTAnalyticsDataset


```text
aws-20210730/Resource/LoT/AwsIoTAnalyticsDataset
```

```text
include('aws-20210730/Resource/LoT/AwsIoTAnalyticsDataset')
```



| Illustration | AwsIoTAnalyticsDataset | AwsIoTAnalyticsDatasetCard | AwsIoTAnalyticsDatasetGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/LoT/AwsIoTAnalyticsDataset.png) | ![illustration for AwsIoTAnalyticsDataset](../../../aws-20210730/Resource/LoT/AwsIoTAnalyticsDataset.Local.png) | ![illustration for AwsIoTAnalyticsDatasetCard](../../../aws-20210730/Resource/LoT/AwsIoTAnalyticsDatasetCard.Local.png) | ![illustration for AwsIoTAnalyticsDatasetGroup](../../../aws-20210730/Resource/LoT/AwsIoTAnalyticsDatasetGroup.Local.png) |




## AwsIoTAnalyticsDataset

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTAnalyticsDataset
include('aws-20210730/Resource/LoT/AwsIoTAnalyticsDataset')

' renders the element
AwsIoTAnalyticsDataset('AwsIoTAnalyticsDataset', 'Aws Io T Analytics Dataset', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTAnalyticsDataset
include('aws-20210730/Resource/LoT/AwsIoTAnalyticsDataset')

' renders the element
AwsIoTAnalyticsDataset('AwsIoTAnalyticsDataset', 'Aws Io T Analytics Dataset', 'an optional tech label')
@enduml
```

## AwsIoTAnalyticsDatasetCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTAnalyticsDatasetCard
include('aws-20210730/Resource/LoT/AwsIoTAnalyticsDataset')

' renders the element
AwsIoTAnalyticsDatasetCard('AwsIoTAnalyticsDatasetCard', 'Aws Io T Analytics Dataset Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTAnalyticsDatasetCard
include('aws-20210730/Resource/LoT/AwsIoTAnalyticsDataset')

' renders the element
AwsIoTAnalyticsDatasetCard('AwsIoTAnalyticsDatasetCard', 'Aws Io T Analytics Dataset Card', 'an optional description')
@enduml
```

## AwsIoTAnalyticsDatasetGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTAnalyticsDatasetGroup
include('aws-20210730/Resource/LoT/AwsIoTAnalyticsDataset')

' renders the element
AwsIoTAnalyticsDatasetGroup('AwsIoTAnalyticsDatasetGroup', 'Aws Io T Analytics Dataset Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTAnalyticsDatasetGroup
include('aws-20210730/Resource/LoT/AwsIoTAnalyticsDataset')

' renders the element
AwsIoTAnalyticsDatasetGroup('AwsIoTAnalyticsDatasetGroup', 'Aws Io T Analytics Dataset Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-20210730/Resource/LoT/AwsIoTAnalyticsDataset.md <==
# AwsIoTAnalyticsDataset


```text
aws-20210730/Resource/LoT/AwsIoTAnalyticsDataset
```

```text
include('aws-20210730/Resource/LoT/AwsIoTAnalyticsDataset')
```



| Illustration | AwsIoTAnalyticsDataset | AwsIoTAnalyticsDatasetCard | AwsIoTAnalyticsDatasetGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/LoT/AwsIoTAnalyticsDataset.png) | ![illustration for AwsIoTAnalyticsDataset](../../../aws-20210730/Resource/LoT/AwsIoTAnalyticsDataset.Local.png) | ![illustration for AwsIoTAnalyticsDatasetCard](../../../aws-20210730/Resource/LoT/AwsIoTAnalyticsDatasetCard.Local.png) | ![illustration for AwsIoTAnalyticsDatasetGroup](../../../aws-20210730/Resource/LoT/AwsIoTAnalyticsDatasetGroup.Local.png) |




## AwsIoTAnalyticsDataset

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTAnalyticsDataset
include('aws-20210730/Resource/LoT/AwsIoTAnalyticsDataset')

' renders the element
AwsIoTAnalyticsDataset('AwsIoTAnalyticsDataset', 'Aws Io T Analytics Dataset', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTAnalyticsDataset
include('aws-20210730/Resource/LoT/AwsIoTAnalyticsDataset')

' renders the element
AwsIoTAnalyticsDataset('AwsIoTAnalyticsDataset', 'Aws Io T Analytics Dataset', 'an optional tech label')
@enduml
```

## AwsIoTAnalyticsDatasetCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTAnalyticsDatasetCard
include('aws-20210730/Resource/LoT/AwsIoTAnalyticsDataset')

' renders the element
AwsIoTAnalyticsDatasetCard('AwsIoTAnalyticsDatasetCard', 'Aws Io T Analytics Dataset Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTAnalyticsDatasetCard
include('aws-20210730/Resource/LoT/AwsIoTAnalyticsDataset')

' renders the element
AwsIoTAnalyticsDatasetCard('AwsIoTAnalyticsDatasetCard', 'Aws Io T Analytics Dataset Card', 'an optional description')
@enduml
```

## AwsIoTAnalyticsDatasetGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTAnalyticsDatasetGroup
include('aws-20210730/Resource/LoT/AwsIoTAnalyticsDataset')

' renders the element
AwsIoTAnalyticsDatasetGroup('AwsIoTAnalyticsDatasetGroup', 'Aws Io T Analytics Dataset Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTAnalyticsDatasetGroup
include('aws-20210730/Resource/LoT/AwsIoTAnalyticsDataset')

' renders the element
AwsIoTAnalyticsDatasetGroup('AwsIoTAnalyticsDatasetGroup', 'Aws Io T Analytics Dataset Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
